library(loadeR)
library(transformeR)
library(ggplot2)
library(RColorBrewer)
library(maps)
library(Kendall)

rm(list=ls()) ; graphics.off() ; gc()

#Directory information
setwd("/esarchive/scratch/molmo/")
OUTPUTS <- "aemet-5km_mon/OUTPUTS/"

#Useful information
season <- list("Winter"=c(12,1,2),"Spring"=c(3,4,5),"Summer"=c(6,7,8),"Autumn"=c(9,10,11),"Annual"=c(1:12))
calendario <- seq(as.Date("1950-01-01"),as.Date("2021-12-31"),by="day")
fechas <- calendario[format(calendario,"%m-%d") != "02-29"]

#Load CPs information
load("WardCluster_Dendrogram_D2_50km.Rdata")
k=5
vector_cluster <- cutree(ward_clustering,k)[which(format(calendario,"%Y")%in%c(1951:2020))]
cp <- loadGridData(dataset = "eobs_tasmax_spain.nc",lonLim = c(-1,1),latLim = c(35,36),var="tasmax")
cp <- aggregateGrid(cp,aggr.spatial = list(FUN="mean"))
for(l in 1:length(cp$Data)){
  cp$Data[l] <- vector_cluster[l]
}

#____________________tasmin_______________________________#
#Load (monthly) surface data
nc <- loadGridData(dataset="aemet-5km_mon/tasmin_aemet-5km_1951-2020.nc",var="tasmin")


mon_intann <- subsetGrid(nc,season=1)

#Generating time-series for each CP
for(l in 1:length(unique(vector_cluster))){
  v <- unique(vector_cluster)[l]
  cp2 <- cp
  cp2$Data[which(cp2$Data!=v)] <- 0
  cp2$Data[which(cp2$Data==v)] <- 1
  index.cp <- aggregateGrid(cp2,aggr.s = list(FUN=list("sum",na.rm=T),season=c(1:12)))
  
  #Removing trend in CP frequency (if any)
  trendfreq  <- lm(index.cp$Data~c(1:length(unique(getYearsAsINDEX(index.cp)))))[["coefficients"]][2]
  index.cp$Data <- index.cp$Data - trendfreq*c(1:length(unique(getYearsAsINDEX(index.cp))))
  
  #Removing trend in surface variable (if any)
  trendfreq  <- lm(index2$Data~c(1:length(unique(getYearsAsINDEX(index2)))))[["coefficients"]][2]
  index2$Data <- index2$Data - trendfreq*c(1:length(unique(getYearsAsINDEX(index2))))
  
  trendfreq.cat  <- lm(index.cat$Data~c(1:length(unique(getYearsAsINDEX(index.cat)))))[["coefficients"]][2]

  value[l] <- as.numeric(Kendall(x=index.cp$Data,y=index2$Data)$tau)
  value.cat[l] <- as.numeric(Kendall(x=index.cp$Data,y=index.cat$Data)$tau)
  
  sign[l] <- as.numeric(Kendall(x=index.cp$Data,y=index2$Data)$sl)
}

data[[1]] <- data.frame(Index=value,
                        Season=rep("Annual",length(value)),
                        CP=unique(vector_cluster),
                        Sign=sign)

#____________________tasmax_______________________________#


#____________________precip_______________________________#
